@@ -8,17 +8,17 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
+import base64
 import random
 import string
+
 import requests
+from captcha.image import ImageCaptcha
 from flask import (
     Blueprint,
     current_app,
     session,
 )
-import base64
-from captcha.image import ImageCaptcha
-
 
 bp = Blueprint("parties", __name__)
 
@@ -34,10 +34,7 @@ def cfgi():
 @bp.route("/parties/captcha", methods=["GET"])
 def captcha():
     val = "".join(
-        [
-            random.choice(string.ascii_lowercase + string.digits)
-            for _ in range(6)
-        ]
+        [random.choice(string.ascii_lowercase + string.digits) for _ in range(6)]
     )
 
     image = ImageCaptcha()
