@@ -9,10 +9,12 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 import secrets
+
 from mongoengine.errors import DoesNotExist, NotUniqueError
+
 from xtcryptosignals.server.api.auth.models import Auth
-from xtcryptosignals.server.api.user.models import UserTokenFavourites
 from xtcryptosignals.server.api.projects.models import Project
+from xtcryptosignals.server.api.user.models import UserTokenFavourites
 from xtcryptosignals.server.api.user.service import get_user
 from xtcryptosignals.server.crypto import Crypto
 from xtcryptosignals.tasks import settings as s
@@ -69,9 +71,7 @@ def get_user_coin_or_token_favourite(auth, coin_or_token):
     except DoesNotExist:
         raise ValueError("Coin or Token does not exist.", 405)
     try:
-        return UserTokenFavourites.objects.get(
-            user=auth.user, coin_token=coin_or_token
-        )
+        return UserTokenFavourites.objects.get(user=auth.user, coin_token=coin_or_token)
     except DoesNotExist:
         raise ValueError("Coin or Token is not in favourites.", 204)
 
@@ -86,9 +86,7 @@ def toggle_user_coin_or_token_favourite(auth, coin_or_token):
         error, status = err.args
         if status == 405:
             raise ValueError(err)
-        UserTokenFavourites.objects.create(
-            user=auth.user, coin_token=coin_or_token
-        )
+        UserTokenFavourites.objects.create(user=auth.user, coin_token=coin_or_token)
 
 
 def get_favourites(auth):
