@@ -8,17 +8,18 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
-import redis
 import json
+
+import redis
 from marshmallow import (
     Schema,
     fields,
     post_dump,
 )
-from xtcryptosignals.common.utils import get_pairs_ex
-from xtcryptosignals.tasks import settings as s
-from xtcryptosignals.server.api.exchanges.binance.service import BinanceAPI
 
+from xtcryptosignals.common.utils import get_pairs_ex
+from xtcryptosignals.server.api.exchanges.binance.service import BinanceAPI
+from xtcryptosignals.tasks import settings as s
 
 red = redis.Redis.from_url(s.BROKER_URL)
 pairs = get_pairs_ex(s.SYMBOLS_PER_EXCHANGE)
@@ -66,9 +67,7 @@ class ExchangeBalanceOutputSchema(Schema):
                 total += x["price"] * x["total"]
             rows.append(x)
 
-        rows = sorted(
-            rows, key=lambda i: i.get("total_price", 0.0), reverse=True
-        )
+        rows = sorted(rows, key=lambda i: i.get("total_price", 0.0), reverse=True)
 
         return dict(results=dict(rows=rows, total=total))
 
@@ -148,9 +147,7 @@ class ExchangeOpenOrdersOutputSchema(Schema):
             total_total += rest * ppc
 
             data["price_buy_average"] = total_total / amount_total
-            data["position"] = (data["price"] * 100) / data[
-                "price_buy_average"
-            ] - 100
+            data["position"] = (data["price"] * 100) / data["price_buy_average"] - 100
             break
 
         if "distance" in data and "position" in data:
@@ -158,9 +155,7 @@ class ExchangeOpenOrdersOutputSchema(Schema):
 
     @post_dump(pass_many=True)
     def post_dump_pass_many(self, data, many):
-        balance_potential = sum(
-            [x["total"] for x in data if x["type"] == "SELL"]
-        )
+        balance_potential = sum([x["total"] for x in data if x["type"] == "SELL"])
         return dict(results=data, balance_potential=balance_potential)
 
 
