@@ -8,12 +8,13 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
-import redis
 import json
-from xtcryptosignals.server.api.transactions.models import Transaction
-from xtcryptosignals.common.utils import get_coin_tokens
-from xtcryptosignals.tasks import settings as s
 
+import redis
+
+from xtcryptosignals.common.utils import get_coin_tokens
+from xtcryptosignals.server.api.transactions.models import Transaction
+from xtcryptosignals.tasks import settings as s
 
 red = redis.Redis.from_url(s.BROKER_URL)
 
@@ -113,9 +114,7 @@ def portfolio(auth):
             {
                 coin_token: dict(
                     reference_info=_get_reference_info_for(coin_token),
-                    current_price=round(
-                        current_price, s.SYMBOL_FLOAT_PRECISION
-                    ),
+                    current_price=round(current_price, s.SYMBOL_FLOAT_PRECISION),
                     units=round(total_units, s.SYMBOL_FLOAT_PRECISION),
                     amount=total_amount,
                     average_paid=average_paid,
