@@ -14,9 +14,10 @@ from mongoengine import (
     ReferenceField,
     DateField,
 )
-from xtcryptosignals.server.api.user.models import User
+
 from xtcryptosignals.common.models import DocumentValidation
 from xtcryptosignals.common.utils import get_coin_tokens
+from xtcryptosignals.server.api.user.models import User
 from xtcryptosignals.tasks import settings as s
 
 
@@ -28,9 +29,7 @@ class Transaction(DocumentValidation):
     coin_token = StringField(
         required=True, choices=get_coin_tokens(s.SYMBOLS_PER_EXCHANGE)
     )
-    units = DecimalField(
-        required=True, min_value=0, precision=s.SYMBOL_FLOAT_PRECISION
-    )
+    units = DecimalField(required=True, min_value=0, precision=s.SYMBOL_FLOAT_PRECISION)
     amount = DecimalField(
         required=True, min_value=0, precision=s.SYMBOL_FLOAT_PRECISION
     )
