@@ -9,7 +9,9 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 from functools import wraps
+
 from flask import request, current_app
+
 from xtcryptosignals.server.api.auth import service
 from xtcryptosignals.tasks import settings as s
 
@@ -60,10 +62,7 @@ def validate_io(
     def decorator(f):
         @wraps(f)
         def wrapper(*args, **kwargs):
-            if (
-                "frequency" in kwargs
-                and kwargs["frequency"] not in s.HISTORY_FREQUENCY
-            ):
+            if "frequency" in kwargs and kwargs["frequency"] not in s.HISTORY_FREQUENCY:
                 return dict(error="Frequency is incorrect."), 400
             if schema_in:
                 try:
