@@ -10,14 +10,14 @@ __email__ = "pjmlantunes@gmail.com"
 
 import cfscrape
 from bs4 import BeautifulSoup
-from etherscan.tokens import Tokens
-from celery.task import task
-from celery.exceptions import Ignore
 from celery import states
-from xtcryptosignals.common.utils import use_mongodb
-from xtcryptosignals.tasks.models.tether import Tether
-from xtcryptosignals.tasks import settings as s
+from celery.exceptions import Ignore
+from celery.task import task
+from etherscan.tokens import Tokens
 
+from xtcryptosignals.common.utils import use_mongodb
+from xtcryptosignals.tasks import settings as s
+from xtcryptosignals.tasks.models.tether import Tether
 
 TETHER_CONTRACT_ADDRESS = "0xdac17f958d2ee523a2206206994597c13d831ec7"
 
@@ -29,9 +29,9 @@ def _get_tether_num_holders():
     soup = BeautifulSoup(scraper.get(URL).content, "html.parser")
 
     try:
-        selector = soup.find(id="ContentPlaceHolder1_tr_tokenHolders").find_all(
-            "div"
-        )[-1]
+        selector = soup.find(id="ContentPlaceHolder1_tr_tokenHolders").find_all("div")[
+            -1
+        ]
     except AttributeError:
         # @note: If fails, most likely CAPTCHA! > can't do anything to prevent it :-(
         return -1
@@ -74,7 +74,7 @@ def update(self):
             api_key=s.ETHERSCAN_API_KEY,
         )
         Tether(
-            total_supply_eth=int(api.get_total_supply()) / 10 ** 6,
+            total_supply_eth=int(api.get_total_supply()) / 10**6,
             num_holders_eth=_get_tether_num_holders(),
         ).save()
 
